@@ -38,6 +38,7 @@ except ImportError:
     print('ERROR - lxml is not installed - try pip install lxml')
     sys.exit()
 
+
 def diff_textfiles(source_textfile, other_textfile):
     '''
     Compares two textfiles. Returns strings that indicate losslessness.
@@ -71,6 +72,7 @@ def make_mediainfo(xmlfilename, xmlvariable, inputfilename):
             xmlvariable = subprocess.check_output(mediainfo_cmd).decode('cp1252')
         fo.write(xmlvariable)
 
+
 def make_exiftool(xmlfilename, inputfilename):
     '''
     Writes an exiftool json output.
@@ -91,6 +93,8 @@ def make_exiftool(xmlfilename, inputfilename):
             with open(inputfilename, 'rb') as file_object:
                 xmlvariable = subprocess.check_output(['exiftool', '-j', '-'], stdin=file_object).decode("utf-8")
         fo.write(xmlvariable)
+
+
 def make_siegfried(xmlfilename, inputfilename):
     '''
     Writes a Siegfried/PRONOM json report.
@@ -106,6 +110,7 @@ def make_siegfried(xmlfilename, inputfilename):
         parsed = json.loads(xmlvariable)
         fo.write(json.dumps(parsed, indent=4, sort_keys=True))
 
+
 def make_mediaconch(full_path, mediaconch_xmlfile):
     '''
     Creates a mediaconch implementation check XML report.
@@ -120,6 +125,7 @@ def make_mediaconch(full_path, mediaconch_xmlfile):
     with open(mediaconch_xmlfile, 'w') as xmlfile:
         xmlfile.write(mediaconch_output)
 
+
 def extract_provenance(filename, output_folder, output_uuid):
     '''
     This will extract dfxml, mediainfo and mediatrace XML
@@ -142,6 +148,7 @@ def extract_provenance(filename, output_folder, output_uuid):
     makedfxml.main([filename, '-n', '-o', dfxml])
     return inputxml, inputtracexml, dfxml
 
+
 def generate_mediainfo_xmls(filename, output_folder, output_uuid, log_name_source):
     '''
     This will add the mediainfo xmls to the package
@@ -161,6 +168,8 @@ def generate_mediainfo_xmls(filename, output_folder, output_uuid, log_name_sourc
         'EVENT = Metadata extraction - eventDetail=File system metadata extraction using Digital Forensics XML, eventOutcome=%s, agentName=makedfxml' % (dfxml)
     )
     return inputxml, inputtracexml, dfxml
+
+
 def make_qctools(input):
     '''
     Runs an ffprobe process that stores QCTools XML info as a variable.
@@ -230,6 +239,7 @@ def get_milliseconds(filename):
     except Exception as e:
             print("\nDuration ERROR\n\t-> get_mediainfo(miliseconds) not support\n\t-> %s\n\t-> ififuncs.py line: 219" % e)
 
+
 def convert_millis(milli):
     '''
     Accepts milliseconds and returns this value as HH:MM:SS.NNN
@@ -296,6 +306,7 @@ def send_gmail(email_to, attachment, subject, email_body, email_address, passwor
     server_ssl.close()
     print(' - successfully sent the mail')
 
+
 def frames_to_seconds(audio_entry_point):
     audio_frame_count = float(audio_entry_point)
     audio_frame_count = float(audio_frame_count) / 24.000 # Change to EditRate variable.
@@ -323,6 +334,17 @@ def generate_log(log, what2log):
                      + ' ' + what2log + ' \n')
 
 
+def generate_txt(txt, what2txt):
+    if not os.path.isfile(txt):
+        with open(txt, "w", encoding='utf-8') as fo:
+            fo.write(time.strftime("Text created time: %Y-%m-%d %H:%M:%S \n")
+                     + 'Script User: ' + getpass.getuser() + ' \n'
+                     + what2txt + ' \n')
+    else:
+        with open(txt, "a", encoding='utf-8') as fo:
+            fo.write(what2txt + ' \n')
+
+
 def hashlib_md5(filename):
     '''
     uses hashlib to return an MD5 checksum of an input filename
@@ -371,6 +393,7 @@ def hashlib_sha512(filename):
     sha512_output = m.hexdigest()
     return sha512_output
 
+
 def hashlib_manifest(manifest_dir, manifest_textfile, path_to_remove):
     '''
     Creates an MD5 manifest with relative filepaths.
@@ -445,6 +468,7 @@ def sha512_manifest(manifest_dir, manifest_textfile, path_to_remove):
         for i in manifest_list:
             fo.write((unicodedata.normalize('NFC', i) + '\n'))
 
+
 def hashlib_append(manifest_dir, manifest_textfile, path_to_remove):
     '''
     Lazy rehash of hashlib_manifest, except this just adds files to an existing manifest.
@@ -497,6 +521,8 @@ def make_manifest(manifest_dir, relative_manifest_path, manifest_textfile):
     else:
         print(' - Manifest already exists')
         sys.exit()
+
+
 def make_mediatrace(tracefilename, xmlvariable, inputfilename):
     mediatrace_cmd = [
             'mediainfo',
@@ -518,7 +544,6 @@ def make_mediatrace(tracefilename, xmlvariable, inputfilename):
         fo.write(xmlvariable)
 
 
-
 def check_overwrite(file2check):
     if os.path.isfile(file2check):
         print(' - A manifest already exists at your destination. Overwrite? Y/N?')
@@ -528,6 +553,8 @@ def check_overwrite(file2check):
             if overwrite_destination_manifest not in ('Y', 'y', 'N', 'n'):
                 print(' - Incorrect input. Please enter Y or N')
         return overwrite_destination_manifest
+
+
 def manifest_file_count(manifest2check):
     '''
     Checks how many entries are in a manifest
@@ -541,7 +568,7 @@ def manifest_file_count(manifest2check):
 
 
 def create_csv(csv_file, *args):
-    f = open(csv_file, 'w', newline='')
+    f = open(csv_file, 'w', encoding='utf-8', newline='')
     try:
         writer = csv.writer(f)
         writer.writerow(*args)
@@ -550,13 +577,14 @@ def create_csv(csv_file, *args):
 
 
 def append_csv(csv_file, *args):
-    f = open(csv_file, 'a', newline='')
+    f = open(csv_file, 'a', encoding='utf-8', newline='')
     try:
         writer = csv.writer(f)
         writer.writerow(*args)
     finally:
         f.close()
 
+
 def sort_csv(csv_file, key):
     '''
     Sorts a csv_file by a key. The key being a field heading.
@@ -572,6 +600,7 @@ def sort_csv(csv_file, key):
             writer.writerow(i)
     return sorted_filepath
 
+
 def make_desktop_manifest_dir():
     desktop_manifest_dir = os.path.expanduser("~/Desktop/moveit_manifests")
     if not os.path.isdir(desktop_manifest_dir):
@@ -591,6 +620,7 @@ def make_desktop_logs_dir():
         os.makedirs(desktop_logs_dir)
     return desktop_logs_dir
 
+
 def get_image_sequence_files(directory):
     # This function accepts a directory as input, and checks returns a list of files in an image sequence.
     os.chdir(directory)
@@ -610,6 +640,7 @@ def get_image_sequence_files(directory):
         return 'none'
     return images
 
+
 def check_multi_reel(directory):
     # This function accepts a directory as input. It checks if there are
     # subdirectories that contain image sequences.
@@ -650,6 +681,7 @@ def get_ffmpeg_friendly_name(images):
             counter += 1
     return ffmpeg_friendly_name, container, start_number
 
+
 def parse_image_sequence(images):
     '''
     Parses image sequence filenames so that they are easily passed to ffmpeg.
@@ -712,6 +744,7 @@ def create_uuid():
     new_uuid = str(uuid.uuid4())
     return new_uuid
 
+
 def make_folder_structure(path):
     '''
     Makes logs, objects, metadata directories in the supplied path
@@ -725,62 +758,42 @@ def make_folder_structure(path):
     os.makedirs(data_dir)
     os.makedirs(log_dir)
 
-
+    
 def get_user():
     '''
     Asks user who they are. Returns a string with their name
     '''
+    user_list = ['Allison McGrail',
+                'Caroline Crowther',
+                'Cody Farren',
+                'Emma Battlebury',
+                'Gavin Martin',
+                'Mark Keleghan',
+                'Matheus Almeida',
+                'Niall Anderson',
+                'Raelene Casey',
+                'Raven Ó Cuacaċ',
+                'Yazhou He']
     user = ''
-    if user not in ('1', '2', '3', '4', '5', '6', '7', '8', '9', '10', '11', '12', '13', '14'):
-        user = input(
-            '\n\n**** Who are you?\nPress 1,2,3,4,5,6,7,8,9,10,11,12,13,14\n\n1.\tKieran O\'Leary\n2.\tRaelene Casey\n3.\tAoife Fitzmaurice\n4.\tYujing Huang\n5.\tNoelia Romero\n6.\tAna Truchanova\n7.\tEoin O\'Donohoe\n8.\tGavin Martin\n9.\tNiamh Murphy\n10.\tRaven Cooke\n11.\tNiall Anderson\n12.\tYazhou He\n13.\tCaroline Crowther\n14.\tMark Keleghan\n'
-        )
-        while user not in ('1', '2', '3', '4', '5', '6', '7', '8', '9', '10', '11', '12', '13', '14'):
-            user = input(
-                '\n\n**** Who are you?\nPress 1,2,3,4,5,6,7,8,9,10,11,12,13,14\n\n1.\tKieran O\'Leary\n2.\tRaelene Casey\n3.\tAoife Fitzmaurice\n4.\tYujing Huang\n5.\tNoelia Romero\n6.\tAna Truchanova\n7.\tEoin O\'Donohoe\n8.\tGavin Martin\n9.\tNiamh Murphy\n10.\tRaven Cooke\n11.\tNiall Anderson\n12.\tYazhou He\n13.\tCaroline Crowther\n14.\tMark Keleghan\n'
-            )
-    if user == '1':
-        user = 'Kieran O\'Leary'
-        time.sleep(1)
-    elif user == '2':
-        user = 'Raelene Casey'
-        time.sleep(1)
-    elif user == '3':
-        user = 'Aoife Fitzmaurice'
-        time.sleep(1)
-    elif user == '4':
-        user = 'Yujing Huang'
-        time.sleep(1)
-    elif user == '5':
-        user = 'Noelia Romero'
-        time.sleep(1)
-    elif user == '6':
-        user = 'Ana Truchanova'
-        time.sleep(1)
-    elif user == '7':
-        user = 'Eoin O\'Donohoe'
-        time.sleep(1)
-    elif user == '8':
-        user = 'Gavin Martin'
-        time.sleep(1)
-    elif user == '9':
-        user = 'Niamh Murphy'
-        time.sleep(1)
-    elif user == '10':
-        user = 'Raven Cooke'
-        time.sleep(1)
-    elif user == '11':
-        user = 'Niall Anderson'
-        time.sleep(1)
-    elif user == '12':
-        user = 'Yazhou He'
-        time.sleep(1)
-    elif user == '13':
-        user = 'Caroline Crowther'
-        time.sleep(1)
-    elif user == '14':
-        user = 'Mark Keleghan'
-        time.sleep(1)
+    if user not in user_list:
+        print('\n\n**** Who are you?\nEnter the number before your name (ie. 1)\n\n')
+        i = 1
+        for user_item in user_list:
+            print(str(i) + '.\t' + user_item)
+            i = i + 1
+        print('\n\n(User list was last updated on 2023-07-06)\n')
+        i = int(input())
+        while i > len(user_list) or i < 1:
+            print('\n\n**** Who are you?\Enter the number before your name (ie. 1)\n\n')
+            i = 1
+            for user_item in user_list:
+                print(str(i) + '.\t' + user_item)
+                i = i + 1
+            print('\n\n(User list was last updated on 2023-07-06)\n')
+            i = int(input())
+    user = user_list[i-1]
+    print('\nUser selected: ' + user)
+    time.sleep(1)
     return user
 
 
@@ -800,39 +813,35 @@ def get_acquisition_type(acquisition_type):
     '''
     Asks user for the type of acquisition
     '''
-    if acquisition_type not in ('1', '2', '4', '5', '7', '8', '13', '14'):
+    if acquisition_type not in ('1', '2', '3', '4', '5', '6'):
         acquisition_type = input(
-            '\n\n**** What is the type of acquisition? - This will not affect Reproductions that have been auto-detected.\nPress 1,2,4,5,7,8,13,14\n\n1. IFB -  deposited  in compliance with IFB delivery requirements\n2. BAI  - deposited  in compliance with BAI delivery requirements\n4. Deposit\n5. Purchased for collection\n7. Unknown at present\n8. Arts Council- deposited in compliance with Arts council delivery requirements\n13. Reproduction\n14. Donation\n'
+            '\n\n**** What is the type of acquisition? - This will not affect Reproductions that have been auto-detected.\nPress 1,2,3,4,5,6\n\n1. Deposit\n2. Deposit via overarching agreements\n3. Donation\n4. Reproduction\n5. Purchased for collection\n6. Unknown at present\n'
         )
-        while acquisition_type not in ('1', '2', '4', '5', '7', '8', '13', '14'):
+        while acquisition_type not in ('1', '2', '3', '4', '5', '6'):
             acquisition_type = input(
-                '\n\n**** What is the type of acquisition? - This will not affect Reproductions that have been auto-detected.\nPress 1,2,4,5,7,8,13,14\n\n1. IFB -  deposited  in compliance with IFB delivery requirements\n2. BAI  - deposited  in compliance with BAI delivery requirements\n4. Deposit\n5. Purchased for collection\n7. Unknown at present\n8. Arts Council- deposited in compliance with Arts council delivery requirements\n13. Reproduction\n14. Donation\n'
+                '\n\n**** What is the type of acquisition? - This will not affect Reproductions that have been auto-detected.\nPress 1,2,3,4,5,6\n\n1. Deposit\n2. Deposit via overarching agreements\n3. Donation\n4. Reproduction\n5. Purchased for collection\n6. Unknown at present\n'
             )
     if acquisition_type == '1':
-        acquisition_type = ['1. IFB -  deposited  in compliance with IFB delivery requirements', 'Deposit', '1']
+        acquisition_type = ['Deposit', 'Deposit', '1']
         time.sleep(1)
     elif acquisition_type == '2':
-        acquisition_type = ['2. BAI  - deposited  in compliance with BAI delivery requirements', 'Deposit', '2']
+        acquisition_type = ['Deposit via overarching agreements', 'Deposit', '2']
+        time.sleep(1)
+    elif acquisition_type == '3':
+        acquisition_type = ['Donation', 'Donation', '3']
         time.sleep(1)
     elif acquisition_type == '4':
-        acquisition_type = ['4. Deposit', 'Deposit', '4']
+        acquisition_type = ['Reproduction', 'Reproduction', '4']
         time.sleep(1)
     elif acquisition_type == '5':
-        acquisition_type = ['5. Purchased for collection', 'Purchase', '5']
-        time.sleep(1)
-    elif acquisition_type == '7':
-        acquisition_type = ['7. Unknown at present', 'Unknown', '7']
-        time.sleep(1)
-    elif acquisition_type == '8':
-        acquisition_type = ['Arts Council- deposited in compliance with Arts council delivery requirements', 'Deposit', '8']
-        time.sleep(1)
-    elif acquisition_type == '13':
-        acquisition_type = ['Reproduction', 'Reproduction', '13']
-        time.sleep(1)
-    elif acquisition_type == '14':
-        acquisition_type = ['Donation', 'Donation', '14']
+        acquisition_type = ['Purchased for collection', 'Purchase', '5']
         time.sleep(1)
+    elif acquisition_type == '6':
+        acquisition_type = ['Unknown at present', 'Unknown', '6']
+        time.sleep(1)        
     return acquisition_type
+
+
 def sort_manifest(manifest_textfile):
     '''
     Sorts an md5 manifest in alphabetical order.
@@ -845,6 +854,7 @@ def sort_manifest(manifest_textfile):
             for i in manifest_list:
                 ba.write(i)
 
+
 def concat_textfile(video_files, concat_file):
     '''
     Create concat textfile for all files in video_files
@@ -895,6 +905,7 @@ def get_temp_concat(root_name):
         video_concat_textfile = temp_dir + "/%s.txt" % video_concat_filename
     return video_concat_textfile
 
+
 def get_script_version(scriptname):
     '''
     uses git to get SHA:DATETIME for a script
@@ -946,6 +957,7 @@ def validate_uuid4(uuid_string):
         # is not a valid hex code for a UUID.
         return False
 
+
 def get_source_uuid():
     '''
     Asks user for uuid. A valid uuid must be provided.
@@ -973,6 +985,7 @@ def ask_question(question):
         proceed = ask_yes_no('Are you really sure?')
     return answer
 
+
 def get_object_entry():
     '''
     Asks user for an Object Entry number. A valid Object Entry (OE####) must be provided.
@@ -996,6 +1009,7 @@ def get_object_entry():
         else:
             return object_entry
 
+
 def get_accession_number():
     '''
     Asks user for an accession number. A valid number (OE####) must be provided.
@@ -1017,15 +1031,17 @@ def get_accession_number():
         else:
             return accession_number
 
-def get_reference_number():
+
+def get_filmo_number():
     '''
-    Asks user for a Filmographic reference number. Due to the variety of reference numbers, validation
-    will be removed for now.
+    Asks user for a Filmographic URN. Due to the variety 
+    of Filmographic URN, validation will be removed for now.
     '''
-    reference_number = input(
-        '\n\n**** Please enter the Filmographic reference number of the representation- if there is more than one work that is represented, seperate them with an ampersand, eg af1234&aa675\n\n'
+    get_filmo_number = input(
+        '\n\n**** Please enter the Filmographic URN of the representation- if there is more than one work that is represented, seperate them with an ampersand, eg af1234&aa675\n\n'
     )
-    return reference_number.upper()
+    return get_filmo_number.upper()
+
 
 def get_contenttitletext(cpl):
     '''
@@ -1050,6 +1066,7 @@ def find_cpl(source):
                     if 'CPL' in cpl_namespace:
                         return os.path.join(root, filename)
 
+
 def ask_yes_no(question):
     '''
     Returns Y or N. The question variable is just a string.
@@ -1065,6 +1082,7 @@ def ask_yes_no(question):
         elif answer in ('N,' 'n'):
             return 'N'
 
+
 def manifest_replace(manifest, to_be_replaced, replaced_with):
     '''
     Replace strings in a checksum manifest (or any textfile)
@@ -1078,6 +1096,7 @@ def manifest_replace(manifest, to_be_replaced, replaced_with):
             new_lines = lines.replace(to_be_replaced, replaced_with)
             ba.write(new_lines)
 
+
 def manifest_update(manifest, path):
     '''
     Adds a new entry to your manifest and sort.
@@ -1104,6 +1123,7 @@ def manifest_update(manifest, path):
         for i in manifest_list:
             fo.write((unicodedata.normalize('NFC', i) + '\n'))
 
+
 def sha512_update(manifest, path):
     '''
     Adds a new entry to your sha512 manifest and sort.
@@ -1130,6 +1150,8 @@ def sha512_update(manifest, path):
     with open(manifest, "w", encoding='utf-8') as fo:
         for i in manifest_list:
             fo.write((unicodedata.normalize('NFC', i) + '\n'))
+
+
 def check_for_uuid(args):
     '''
     Tries to check if a filepath contains a UUID.
@@ -1151,6 +1173,7 @@ def check_for_uuid(args):
             else:
                 return source_uuid
 
+
 def check_for_uuid_generic(source):
     '''
     Tries to check if a filepath contains a UUID.
@@ -1192,6 +1215,7 @@ def check_for_sip(args):
             if os.path.isdir(os.path.join(args[0], dircheck)):
                 return os.path.join(args[0], dircheck)
 
+
 def check_for_sip_generic(source):
     '''
     This checks if the input folder contains the actual payload, eg:
@@ -1206,6 +1230,7 @@ def check_for_sip_generic(source):
             if os.path.isdir(os.path.join(source, dircheck)):
                 return os.path.join(source, dircheck)
 
+
 def checksum_replace(manifest, logname, algorithm):
     '''
     Update a value in a checksum manifest.
@@ -1229,6 +1254,7 @@ def checksum_replace(manifest, logname, algorithm):
         for lines in updated_manifest:
             fo.write(lines)
 
+
 def img_seq_pixfmt(start_number, path):
     '''
     Determine the pixel format of an image sequence
@@ -1246,6 +1272,7 @@ def img_seq_pixfmt(start_number, path):
     pix_fmt = subprocess.check_output(ffprobe_cmd).rstrip().decode(sys.stdout.encoding)
     return pix_fmt
 
+
 def get_ffmpeg_fmt(path, file_type):
     '''
     Determine the pixel format or audio format of a file
@@ -1265,9 +1292,15 @@ def get_ffmpeg_fmt(path, file_type):
         metadata,
         '-of', 'default=noprint_wrappers=1:nokey=1'
     ]
-    pix_fmt = subprocess.check_output(ffprobe_cmd).rstrip().decode(sys.stdout.encoding).replace("\n", '|').replace("\r", '')
+    try:
+        pix_fmt = subprocess.check_output(ffprobe_cmd).rstrip().decode(sys.stdout.encoding).replace("\n", '|').replace("\r", '')
+    except subprocess.CalledProcessError as grepexc:
+        print(grepexc)
+        print("***** %s\n\tCannot recognise the value of pixel/audio format of this %s file/track.\n\tValue is replaced by 'missing_metadata*'.\n\tCheck after script finishes." % (path, file_type))
+        pix_fmt = 'missing_metadata*'
     return pix_fmt
 
+
 def get_number_of_tracks(path):
     '''
     Get number of tracks in a instantationTracks style output
@@ -1281,7 +1314,12 @@ def get_number_of_tracks(path):
         'stream=codec_type',
         '-of', 'default=noprint_wrappers=1:nokey=1'
     ]
-    type_list = subprocess.check_output(ffprobe_cmd).rstrip().decode(sys.stdout.encoding).splitlines()
+    try:
+        type_list = subprocess.check_output(ffprobe_cmd).rstrip().decode(sys.stdout.encoding).splitlines()
+    except subprocess.CalledProcessError as grepexc:
+        print(grepexc)
+        print("***** %s\n\tCannot recognise this file/track type is [video] or [audio].\n\tValue is replaced by 'missing_metadata*'.\n\tCheck after script finishes." % path)
+        type_list = ['missing_metadata*']
     types = {}
     final_count = ''
     for i in type_list:
@@ -1321,6 +1359,7 @@ def merge_logs(log_name_source, sipcreator_log, sipcreator_manifest):
             fo.write(remaining_lines)
     checksum_replace(sipcreator_manifest, sipcreator_log, 'md5')
 
+
 def merge_logs_append(log_name_source, sipcreator_log, sipcreator_manifest):
     '''
     merges the contents of one log with another.
@@ -1338,6 +1377,8 @@ def merge_logs_append(log_name_source, sipcreator_log, sipcreator_manifest):
         for remaining_lines in concat_lines:
             fo.write(remaining_lines)
     checksum_replace(sipcreator_manifest, sipcreator_log, 'md5')
+
+
 def logname_check(basename, logs_dir):
     '''
     Currently we have a few different logname patterns in our packages.
@@ -1375,7 +1416,7 @@ def log_results(manifest, log, parent_dir):
     logs_dir = os.path.join(sip_dir, 'logs')
     logname = logname_check(basename, logs_dir)
     logfile = os.path.join(logs_dir, logname)
-    ififuncs.generate_log(
+    generate_log(
         log,
         'EVENT = Logs consolidation - Log from %s merged into %s' % (log, logfile)
     )
@@ -1389,12 +1430,13 @@ def log_results(manifest, log, parent_dir):
         manifest_lines = manifesto.readlines()
         for lines in manifest_lines:
             if os.path.basename(logname) in lines:
-                lines = lines[:31].replace(lines[:31], ififuncs.hashlib_md5(logfile)) + lines[32:]
+                lines = lines[:31].replace(lines[:31], hashlib_md5(logfile)) + lines[32:]
             updated_manifest.append(lines)
     with open(manifest, 'w') as fo:
         for lines in updated_manifest:
             fo.write(lines)
 
+
 def find_parent(sipcreator_log,oe_uuid_dict):
     '''
     Looks through a concat logfile in order to determine the parent OE number.
@@ -1414,6 +1456,7 @@ def find_parent(sipcreator_log,oe_uuid_dict):
         if line_check == '':
             return '%s not a child of another package' % os.path.basename(os.path.dirname(os.path.dirname(os.path.dirname(sipcreator_log))))
 
+
 def find_concat_user(sipcreator_log):
     '''
     Looks through a concat logfile in order to determine the user.
@@ -1438,12 +1481,13 @@ def group_ids(source):
         if os.path.basename(root)[:2] == 'oe':
             if validate_uuid4(dirnames[0]) is not False:
                 uuid_oe_dict[os.path.basename(root)] = dirnames[0]
-        # check for accessioned packages
+        # check for AIPs
         elif os.path.basename(root)[:3] == 'aaa':
             if validate_uuid4(dirnames[0]) is not False:
                 uuid_oe_dict[os.path.basename(root)] = dirnames[0]
     return uuid_oe_dict
 
+
 def convert_ms2frames(fps, ms):
     # taken from https://github.com/atvKumar/Scene_Cut_Detection/blob/93622d250dc38907ee7d3ee8d925c4bfb76129b6/timecode_utils.py'
     # I am worried that this does not produce 100% accurate values, however
@@ -1474,7 +1518,7 @@ def recursive_file_list(video_files):
     recursive_list = []
     for root, _, filenames in os.walk(video_files):
         for filename in filenames:
-            if filename.endswith(('.MP4', '.mp4', '.MOV', '.mov', '.mkv', '.mxf', '.MXF', '.WAV', '.wav', '.aiff', '.AIFF', 'mp3', 'MP3', 'm2t', '.dv', '.DV', '.iso', '.ISO')):
+            if filename.endswith(('.MP4', '.mp4', '.MOV', '.mov', '.mkv', '.mxf', '.MXF', '.WAV', '.wav', '.aiff', '.AIFF', 'mp3', 'MP3', 'm2t', 'MTS', '.dv', '.DV', '.iso', '.ISO')):
                 recursive_list.append(os.path.join(root, filename))
     return recursive_list
 
@@ -1494,6 +1538,7 @@ def get_video_files(source):
         file_list = [source]
     return file_list
 
+
 def extract_metadata(csv_file):
     '''
     Read the csv and store the data in a list of dictionaries.
@@ -1505,6 +1550,7 @@ def extract_metadata(csv_file):
         object_dictionaries.append(rows)
     return object_dictionaries, headers
 
+
 def check_dependencies(dependencies):
     '''
     Checks a list of external subprocess dependencies and informs the user
@@ -1624,6 +1670,7 @@ def get_digital_object_descriptor(source_folder):
         dig_object_descriptor = 'MPEG-2 Transport Stream'
     return dig_object_descriptor
 
+
 def check_for_fcp(filename):
     '''
     Final Cut Pro 7 Capture files have some significant missing metadata that
@@ -1663,6 +1710,7 @@ def check_for_fcp(filename):
                 if width == '720':
                     return True
 
+
 def check_for_blackmagic(filename):
     '''
     Blackmagic Media Express writes a lot of significant metadata
@@ -1704,6 +1752,8 @@ def check_for_blackmagic(filename):
             if height_clap == '576':
                 if width_clap == '702':
                     return True
+
+
 def read_non_comment_lines(infile):
     '''
     This was pulled from makeffv1, and it looks like the key line has actually been commented out.
@@ -1735,6 +1785,7 @@ def diff_framemd5s(fmd5, fmd5ffv1):
                         checksum_mismatches.append(1)
     return checksum_mismatches
 
+
 def get_mediainfo_version():
     '''
     Returns the version of mediainfo.
@@ -1749,6 +1800,7 @@ def get_mediainfo_version():
         mediainfo_version = grepexc.output.rstrip().splitlines()[1]
     return mediainfo_version
 
+
 def get_rawcooked_version():
     '''
     Returns the version of rawcooked.
@@ -1763,6 +1815,7 @@ def get_rawcooked_version():
         rawcooked_version = grepexc.output.rstrip().splitlines()[1]
     return rawcooked_version
 
+
 def get_ffprobe_dict(source):
     '''
     Returns a dictionary via the ffprobe JSON output
@@ -1772,6 +1825,7 @@ def get_ffprobe_dict(source):
     ffprobe_dict = json.loads(ffprobe_json)
     return ffprobe_dict
 
+
 def get_colour_metadata(ffprobe_dict):
     '''
     Parses through a ffprobe dictionary and extracts colour metadata.
@@ -1808,6 +1862,7 @@ def get_colour_metadata(ffprobe_dict):
             continue
     return ffmpeg_colour_list
 
+
 def get_metadata(xpath_path, root, pbcore_namespace):
     '''
     Extracts values from PBCore2 XML MediaInfo outputs.
@@ -1845,6 +1900,7 @@ def get_metadata(xpath_path, root, pbcore_namespace):
         value = value[0].text
     return value
 
+
 def choose_cpl(cpl_list):
     # Some DCPs have multiple CPLs!
     cpl_number = 1
@@ -1871,6 +1927,7 @@ def find_cpl(source):
                 try:
                     xmlname = etree.parse(full_path)
                 except SyntaxError:
+                    print(full_path)
                     print( 'not a valid CPL!')
                     continue
                 except KeyError:
@@ -2006,6 +2063,7 @@ def get_technical_metadata(path, new_log_textfile):
                         'EVENT = Format identification - eventType=format identification, eventDetail=Format identification via PRONOM signatures using Siegfried, eventOutcome=%s, agentName=%s' % (inputtracexml, siegfried_version)
                     )
                     
+
 def check_if_manifest(manifest):
     '''
     Basic check to see if a file is an md5 manifest
@@ -2017,6 +2075,7 @@ def check_if_manifest(manifest):
                 if not manifest.endswith('_modified_manifest.md5'):
                     return True
 
+
 def count_stuff(source):
     '''
     Counts total files to be processed.
@@ -2036,6 +2095,7 @@ def count_stuff(source):
             source_count = 1
     return source_count, file_list
 
+
 def check_existence(dependency_list):
     '''
     Process a list of subprocess strings and check if they're installed
@@ -2049,3 +2109,4 @@ def check_existence(dependency_list):
         print('Exiting')
         sys.exit()
 
+
