@@ -15,6 +15,7 @@ Get rid of this technical debt!
 '''
 import sys
 import os
+import time
 import subprocess
 import argparse
 import lxml
@@ -148,12 +149,8 @@ def parse_args(args_):
         help='Declare who you are. If this is not set, you will be prompted.'
     )
     parser.add_argument(
-        '-accession',
-        help='Enter the Accession number for the representation.'
-    )
-    parser.add_argument(
-        '-reference',
-        help='Enter the Filmographic reference number for the representation.'
+        '-filmo_number',
+        help='Enter the Filmographic URN for the representation.'
     )
     parser.add_argument(
         '-p', action='store_true',
@@ -189,7 +186,7 @@ def parse_args(args_):
 
 def get_accession_number(source):
     '''
-    Checks if the package has been accessioned.
+    Checks if the AIP has been created.
     Returns the accession number if this is the case, otherwise the script exits.
     '''
     basename = os.path.basename(source)
@@ -197,13 +194,13 @@ def get_accession_number(source):
         if basename[:3] == 'aaa':
             return basename
     else:
-        print('looks like your package has not been accessioned? Exiting!')
-        return 'not_accessioned'
+        print('looks like your AIP has not been created? Exiting!')
+        return 'not_AIPed'
 
 
-def get_reference_number(source):
+def get_filmo_number(source):
     '''
-    Checks if the reference number is in the folder path.
+    Checks if the filmographic URN is in the folder path.
     This check is not sustainable, will have to be made more flexible!
     '''
     basename = os.path.basename(os.path.dirname(source))
@@ -211,7 +208,7 @@ def get_reference_number(source):
         if basename[:3] == 'af1':
             return basename
     else:
-        basename = ififuncs.get_reference_number()
+        basename = ififuncs.get_filmo_number()
         return basename
 
 
@@ -365,10 +362,10 @@ def main(args_):
         if ififuncs.validate_uuid4(dirs) is None:
             instantiationIdentif = dirs
     Accession_Number = get_accession_number(args.input)
-    if args.reference:
-        Reference_Number = args.reference.upper()
+    if args.filmo_number:
+        Reference_Number = args.filmo_number.upper()
     else:
-        Reference_Number = get_reference_number(args.input)
+        Reference_Number = get_filmo_number(args.input)
     if args.p:
         for root, _, filenames in os.walk(args.input):
             if os.path.basename(root) == 'metadata':
@@ -432,6 +429,7 @@ def main(args_):
     video_codec_profile_list = []
     timecode_list = []
     channels_list = []
+    failed_path = []
     stl = False
     subtitle_check = ififuncs.get_digital_object_descriptor(args.input)
     if 'STL' in subtitle_check:
@@ -563,6 +561,8 @@ def main(args_):
         except Exception as e:
             print("\ninstantDataRate ERROR\n\t-> get_mediainfo(OverallBitRate) not support\n\t-> %s\n\t-> makepbcore.py line: 560\n\t\t-> ififuncs.py line: 200" % e)
         instantTracks = ififuncs.get_number_of_tracks(source)
+        if instantTracks == 'missing_metadata*':
+            failed_path.append(source)
         track_count_list.append(instantTracks)
         if stl is True:
             track_count_list.append('STL sidecar')
@@ -671,8 +671,12 @@ def main(args_):
         instantDate_other = 'n/a'
         instantDate_type = 'n/a'
         pix_fmt = ififuncs.get_ffmpeg_fmt(source, 'video')
+        if pix_fmt == 'missing_metadata*':
+            failed_path.append(source)
         pix_fmt_list.append(pix_fmt)
         audio_fmt = ififuncs.get_ffmpeg_fmt(source, 'audio')
+        if audio_fmt == 'missing_metadata*':
+            failed_path.append(source)
         audio_fmt_list.append(audio_fmt)
         essenceBitDepth_vid = ififuncs.get_mediainfo(
             'duration', '--inform=Video;%BitDepth%', source
@@ -886,6 +890,16 @@ def main(args_):
         ififuncs.sha512_update(sha512_manifest, csv_filename)
         print((' - Updating %s with %s' % (sha512_manifest, csv_filename)))
         print(metadata_error)
+    if failed_path:
+        desktop_logs_dir = ififuncs.make_desktop_logs_dir()
+        txt_name_filename = 'pbcore_corrupted_metadata' + time.strftime("_%Y_%m_%dT%H_%M_%S")
+        txt_name_source = "%s/%s.txt" % (desktop_logs_dir, txt_name_filename)
+        print("***** [missing_metadata*] The source path(s) shown below contain corrupted metadata.\n\tRepeated locations mean the absence of metadata in multiple fields.\n\tCheck the details above or in the %s.txt in Desktop/ifiscripts_log folder." % txt_name_filename)
+        ififuncs.generate_txt(txt_name_source, '[missing_metadata*] The source path(s) shown below contain corrupted metadata.\nRepeated locations mean the absence of metadata in multiple fields.')
+        for i in failed_path:
+            print(i)
+            ififuncs.generate_txt(txt_name_source, i)
+
 if __name__ == '__main__':
     main(sys.argv[1:])
 
